# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class WorkerHeartbeat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time': 'datetime',
        'clock': 'int',
        'active': 'int',
        'processed': 'int',
        'load': 'object'
    }

    attribute_map = {
        'time': 'time',
        'clock': 'clock',
        'active': 'active',
        'processed': 'processed',
        'load': 'load'
    }

    def __init__(self, time=None, clock=None, active=None, processed=None, load=None, local_vars_configuration=None):  # noqa: E501
        """WorkerHeartbeat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._clock = None
        self._active = None
        self._processed = None
        self._load = None
        self.discriminator = None

        self.time = time
        self.clock = clock
        self.active = active
        self.processed = processed
        self.load = load

    @property
    def time(self):
        """Gets the time of this WorkerHeartbeat.  # noqa: E501

        The time of the heartbeat.  # noqa: E501

        :return: The time of this WorkerHeartbeat.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this WorkerHeartbeat.

        The time of the heartbeat.  # noqa: E501

        :param time: The time of this WorkerHeartbeat.  # noqa: E501
        :type time: datetime
        """
        if self.local_vars_configuration.client_side_validation and time is None:  # noqa: E501
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def clock(self):
        """Gets the clock of this WorkerHeartbeat.  # noqa: E501

        The tick number of the worker's monotonic clock  # noqa: E501

        :return: The clock of this WorkerHeartbeat.  # noqa: E501
        :rtype: int
        """
        return self._clock

    @clock.setter
    def clock(self, clock):
        """Sets the clock of this WorkerHeartbeat.

        The tick number of the worker's monotonic clock  # noqa: E501

        :param clock: The clock of this WorkerHeartbeat.  # noqa: E501
        :type clock: int
        """
        if self.local_vars_configuration.client_side_validation and clock is None:  # noqa: E501
            raise ValueError("Invalid value for `clock`, must not be `None`")  # noqa: E501

        self._clock = clock

    @property
    def active(self):
        """Gets the active of this WorkerHeartbeat.  # noqa: E501

        The number of active jobs on the worker.  # noqa: E501

        :return: The active of this WorkerHeartbeat.  # noqa: E501
        :rtype: int
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this WorkerHeartbeat.

        The number of active jobs on the worker.  # noqa: E501

        :param active: The active of this WorkerHeartbeat.  # noqa: E501
        :type active: int
        """
        if self.local_vars_configuration.client_side_validation and active is None:  # noqa: E501
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def processed(self):
        """Gets the processed of this WorkerHeartbeat.  # noqa: E501

        The number of jobs that have been processed by the worker.  # noqa: E501

        :return: The processed of this WorkerHeartbeat.  # noqa: E501
        :rtype: int
        """
        return self._processed

    @processed.setter
    def processed(self, processed):
        """Sets the processed of this WorkerHeartbeat.

        The number of jobs that have been processed by the worker.  # noqa: E501

        :param processed: The processed of this WorkerHeartbeat.  # noqa: E501
        :type processed: int
        """
        if self.local_vars_configuration.client_side_validation and processed is None:  # noqa: E501
            raise ValueError("Invalid value for `processed`, must not be `None`")  # noqa: E501

        self._processed = processed

    @property
    def load(self):
        """Gets the load of this WorkerHeartbeat.  # noqa: E501

        An array of the system load over the last 1, 5 and 15 minutes. From os.getloadavg().  # noqa: E501

        :return: The load of this WorkerHeartbeat.  # noqa: E501
        :rtype: object
        """
        return self._load

    @load.setter
    def load(self, load):
        """Sets the load of this WorkerHeartbeat.

        An array of the system load over the last 1, 5 and 15 minutes. From os.getloadavg().  # noqa: E501

        :param load: The load of this WorkerHeartbeat.  # noqa: E501
        :type load: object
        """
        if self.local_vars_configuration.client_side_validation and load is None:  # noqa: E501
            raise ValueError("Invalid value for `load`, must not be `None`")  # noqa: E501

        self._load = load

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkerHeartbeat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkerHeartbeat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class AccountUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'user': 'int',
        'creator': 'int',
        'created': 'datetime',
        'display_name': 'str',
        'location': 'str',
        'image': 'str',
        'website': 'str',
        'email': 'str',
        'theme': 'str',
        'extra_head': 'str',
        'extra_top': 'str',
        'extra_bottom': 'str',
        'hosts': 'str',
        'first_name': 'str',
        'last_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'user': 'user',
        'creator': 'creator',
        'created': 'created',
        'display_name': 'displayName',
        'location': 'location',
        'image': 'image',
        'website': 'website',
        'email': 'email',
        'theme': 'theme',
        'extra_head': 'extraHead',
        'extra_top': 'extraTop',
        'extra_bottom': 'extraBottom',
        'hosts': 'hosts',
        'first_name': 'firstName',
        'last_name': 'lastName'
    }

    def __init__(self, id=None, name=None, user=None, creator=None, created=None, display_name=None, location=None, image=None, website=None, email=None, theme=None, extra_head=None, extra_top=None, extra_bottom=None, hosts=None, first_name='', last_name='', local_vars_configuration=None):  # noqa: E501
        """AccountUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._user = None
        self._creator = None
        self._created = None
        self._display_name = None
        self._location = None
        self._image = None
        self._website = None
        self._email = None
        self._theme = None
        self._extra_head = None
        self._extra_top = None
        self._extra_bottom = None
        self._hosts = None
        self._first_name = None
        self._last_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.user = user
        if creator is not None:
            self.creator = creator
        if created is not None:
            self.created = created
        self.display_name = display_name
        self.location = location
        self.image = image
        self.website = website
        self.email = email
        if theme is not None:
            self.theme = theme
        self.extra_head = extra_head
        self.extra_top = extra_top
        self.extra_bottom = extra_bottom
        self.hosts = hosts
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name

    @property
    def id(self):
        """Gets the id of this AccountUpdate.  # noqa: E501


        :return: The id of this AccountUpdate.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AccountUpdate.


        :param id: The id of this AccountUpdate.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AccountUpdate.  # noqa: E501

        Name of the account. Lowercase and no spaces or leading numbers. Will be used in URLS e.g. https://hub.stenci.la/awesome-org  # noqa: E501

        :return: The name of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountUpdate.

        Name of the account. Lowercase and no spaces or leading numbers. Will be used in URLS e.g. https://hub.stenci.la/awesome-org  # noqa: E501

        :param name: The name of this AccountUpdate.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def user(self):
        """Gets the user of this AccountUpdate.  # noqa: E501

        The user for this account. Only applies to personal accounts.  # noqa: E501

        :return: The user of this AccountUpdate.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this AccountUpdate.

        The user for this account. Only applies to personal accounts.  # noqa: E501

        :param user: The user of this AccountUpdate.  # noqa: E501
        :type user: int
        """

        self._user = user

    @property
    def creator(self):
        """Gets the creator of this AccountUpdate.  # noqa: E501

        The user who created the account.  # noqa: E501

        :return: The creator of this AccountUpdate.  # noqa: E501
        :rtype: int
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this AccountUpdate.

        The user who created the account.  # noqa: E501

        :param creator: The creator of this AccountUpdate.  # noqa: E501
        :type creator: int
        """

        self._creator = creator

    @property
    def created(self):
        """Gets the created of this AccountUpdate.  # noqa: E501

        The time the account was created.  # noqa: E501

        :return: The created of this AccountUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AccountUpdate.

        The time the account was created.  # noqa: E501

        :param created: The created of this AccountUpdate.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def display_name(self):
        """Gets the display_name of this AccountUpdate.  # noqa: E501

        Name to display in account profile.  # noqa: E501

        :return: The display_name of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this AccountUpdate.

        Name to display in account profile.  # noqa: E501

        :param display_name: The display_name of this AccountUpdate.  # noqa: E501
        :type display_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 256):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `256`")  # noqa: E501

        self._display_name = display_name

    @property
    def location(self):
        """Gets the location of this AccountUpdate.  # noqa: E501

        Location to display in account profile.  # noqa: E501

        :return: The location of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this AccountUpdate.

        Location to display in account profile.  # noqa: E501

        :param location: The location of this AccountUpdate.  # noqa: E501
        :type location: str
        """
        if (self.local_vars_configuration.client_side_validation and
                location is not None and len(location) > 256):
            raise ValueError("Invalid value for `location`, length must be less than or equal to `256`")  # noqa: E501

        self._location = location

    @property
    def image(self):
        """Gets the image of this AccountUpdate.  # noqa: E501

        Image for the account.  # noqa: E501

        :return: The image of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this AccountUpdate.

        Image for the account.  # noqa: E501

        :param image: The image of this AccountUpdate.  # noqa: E501
        :type image: str
        """

        self._image = image

    @property
    def website(self):
        """Gets the website of this AccountUpdate.  # noqa: E501

        URL to display in account profile.  # noqa: E501

        :return: The website of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this AccountUpdate.

        URL to display in account profile.  # noqa: E501

        :param website: The website of this AccountUpdate.  # noqa: E501
        :type website: str
        """
        if (self.local_vars_configuration.client_side_validation and
                website is not None and len(website) > 200):
            raise ValueError("Invalid value for `website`, length must be less than or equal to `200`")  # noqa: E501

        self._website = website

    @property
    def email(self):
        """Gets the email of this AccountUpdate.  # noqa: E501

        An email to display in account profile. Will not be used by Stencila to contact you.  # noqa: E501

        :return: The email of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AccountUpdate.

        An email to display in account profile. Will not be used by Stencila to contact you.  # noqa: E501

        :param email: The email of this AccountUpdate.  # noqa: E501
        :type email: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 254):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `254`")  # noqa: E501

        self._email = email

    @property
    def theme(self):
        """Gets the theme of this AccountUpdate.  # noqa: E501

        The default theme for the account.  # noqa: E501

        :return: The theme of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._theme

    @theme.setter
    def theme(self, theme):
        """Sets the theme of this AccountUpdate.

        The default theme for the account.  # noqa: E501

        :param theme: The theme of this AccountUpdate.  # noqa: E501
        :type theme: str
        """
        allowed_values = ["bootstrap", "elife", "f1000", "galleria", "giga", "latex", "nature", "plos", "rpng", "skeleton", "stencila", "tufte", "wilmore"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and theme not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `theme` ({0}), must be one of {1}"  # noqa: E501
                .format(theme, allowed_values)
            )

        self._theme = theme

    @property
    def extra_head(self):
        """Gets the extra_head of this AccountUpdate.  # noqa: E501

        Content to inject into the <head> element of HTML served for this account.  # noqa: E501

        :return: The extra_head of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_head

    @extra_head.setter
    def extra_head(self, extra_head):
        """Sets the extra_head of this AccountUpdate.

        Content to inject into the <head> element of HTML served for this account.  # noqa: E501

        :param extra_head: The extra_head of this AccountUpdate.  # noqa: E501
        :type extra_head: str
        """

        self._extra_head = extra_head

    @property
    def extra_top(self):
        """Gets the extra_top of this AccountUpdate.  # noqa: E501

        Content to inject at the top of the <body> element of HTML served for this account.  # noqa: E501

        :return: The extra_top of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_top

    @extra_top.setter
    def extra_top(self, extra_top):
        """Sets the extra_top of this AccountUpdate.

        Content to inject at the top of the <body> element of HTML served for this account.  # noqa: E501

        :param extra_top: The extra_top of this AccountUpdate.  # noqa: E501
        :type extra_top: str
        """

        self._extra_top = extra_top

    @property
    def extra_bottom(self):
        """Gets the extra_bottom of this AccountUpdate.  # noqa: E501

        Content to inject at the bottom of the <body> element of HTML served for this account.  # noqa: E501

        :return: The extra_bottom of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_bottom

    @extra_bottom.setter
    def extra_bottom(self, extra_bottom):
        """Sets the extra_bottom of this AccountUpdate.

        Content to inject at the bottom of the <body> element of HTML served for this account.  # noqa: E501

        :param extra_bottom: The extra_bottom of this AccountUpdate.  # noqa: E501
        :type extra_bottom: str
        """

        self._extra_bottom = extra_bottom

    @property
    def hosts(self):
        """Gets the hosts of this AccountUpdate.  # noqa: E501

        A space separated list of valid hosts for the account. Used for setting Content Security Policy headers when serving content for this account.  # noqa: E501

        :return: The hosts of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this AccountUpdate.

        A space separated list of valid hosts for the account. Used for setting Content Security Policy headers when serving content for this account.  # noqa: E501

        :param hosts: The hosts of this AccountUpdate.  # noqa: E501
        :type hosts: str
        """

        self._hosts = hosts

    @property
    def first_name(self):
        """Gets the first_name of this AccountUpdate.  # noqa: E501

        Your first names (given names).  # noqa: E501

        :return: The first_name of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this AccountUpdate.

        Your first names (given names).  # noqa: E501

        :param first_name: The first_name of this AccountUpdate.  # noqa: E501
        :type first_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) < 1):
            raise ValueError("Invalid value for `first_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this AccountUpdate.  # noqa: E501

        Your last names (family names, surnames).  # noqa: E501

        :return: The last_name of this AccountUpdate.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this AccountUpdate.

        Your last names (family names, surnames).  # noqa: E501

        :param last_name: The last_name of this AccountUpdate.  # noqa: E501
        :type last_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) < 1):
            raise ValueError("Invalid value for `last_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._last_name = last_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class User(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'username': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'display_name': 'str',
        'location': 'str',
        'image': 'AccountImage',
        'website': 'str',
        'public_email': 'str'
    }

    attribute_map = {
        'id': 'id',
        'username': 'username',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'display_name': 'displayName',
        'location': 'location',
        'image': 'image',
        'website': 'website',
        'public_email': 'publicEmail'
    }

    def __init__(self, id=None, username=None, first_name=None, last_name=None, display_name=None, location=None, image=None, website=None, public_email=None, local_vars_configuration=None):  # noqa: E501
        """User - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._username = None
        self._first_name = None
        self._last_name = None
        self._display_name = None
        self._location = None
        self._image = None
        self._website = None
        self._public_email = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.username = username
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if display_name is not None:
            self.display_name = display_name
        if location is not None:
            self.location = location
        if image is not None:
            self.image = image
        if website is not None:
            self.website = website
        if public_email is not None:
            self.public_email = public_email

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501


        :return: The id of this User.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.


        :param id: The id of this User.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def username(self):
        """Gets the username of this User.  # noqa: E501

        Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.  # noqa: E501

        :return: The username of this User.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this User.

        Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.  # noqa: E501

        :param username: The username of this User.  # noqa: E501
        :type username: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) > 150):
            raise ValueError("Invalid value for `username`, length must be less than or equal to `150`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) < 1):
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and not re.search(r'^[\w.@+-]+$', username)):  # noqa: E501
            raise ValueError(r"Invalid value for `username`, must be a follow pattern or equal to `/^[\w.@+-]+$/`")  # noqa: E501

        self._username = username

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501


        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.


        :param first_name: The first_name of this User.  # noqa: E501
        :type first_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) > 150):
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `150`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501


        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.


        :param last_name: The last_name of this User.  # noqa: E501
        :type last_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) > 150):
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `150`")  # noqa: E501

        self._last_name = last_name

    @property
    def display_name(self):
        """Gets the display_name of this User.  # noqa: E501


        :return: The display_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this User.


        :param display_name: The display_name of this User.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def location(self):
        """Gets the location of this User.  # noqa: E501


        :return: The location of this User.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this User.


        :param location: The location of this User.  # noqa: E501
        :type location: str
        """

        self._location = location

    @property
    def image(self):
        """Gets the image of this User.  # noqa: E501


        :return: The image of this User.  # noqa: E501
        :rtype: AccountImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this User.


        :param image: The image of this User.  # noqa: E501
        :type image: AccountImage
        """

        self._image = image

    @property
    def website(self):
        """Gets the website of this User.  # noqa: E501


        :return: The website of this User.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this User.


        :param website: The website of this User.  # noqa: E501
        :type website: str
        """

        self._website = website

    @property
    def public_email(self):
        """Gets the public_email of this User.  # noqa: E501


        :return: The public_email of this User.  # noqa: E501
        :rtype: str
        """
        return self._public_email

    @public_email.setter
    def public_email(self, public_email):
        """Sets the public_email of this User.


        :param public_email: The public_email of this User.  # noqa: E501
        :type public_email: str
        """

        self._public_email = public_email

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, User):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class ProjectUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'account': 'int',
        'creator': 'int',
        'created': 'datetime',
        'name': 'str',
        'title': 'str',
        'description': 'str',
        'temporary': 'bool',
        'public': 'bool',
        'key': 'str',
        'main': 'str',
        'container_image': 'str',
        'liveness': 'str',
        'pinned': 'str',
        'theme': 'str',
        'extra_head': 'str',
        'extra_top': 'str',
        'extra_bottom': 'str'
    }

    attribute_map = {
        'id': 'id',
        'account': 'account',
        'creator': 'creator',
        'created': 'created',
        'name': 'name',
        'title': 'title',
        'description': 'description',
        'temporary': 'temporary',
        'public': 'public',
        'key': 'key',
        'main': 'main',
        'container_image': 'containerImage',
        'liveness': 'liveness',
        'pinned': 'pinned',
        'theme': 'theme',
        'extra_head': 'extraHead',
        'extra_top': 'extraTop',
        'extra_bottom': 'extraBottom'
    }

    def __init__(self, id=None, account=None, creator=None, created=None, name=None, title=None, description=None, temporary=None, public=None, key=None, main=None, container_image=None, liveness=None, pinned=None, theme=None, extra_head=None, extra_top=None, extra_bottom=None, local_vars_configuration=None):  # noqa: E501
        """ProjectUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._account = None
        self._creator = None
        self._created = None
        self._name = None
        self._title = None
        self._description = None
        self._temporary = None
        self._public = None
        self._key = None
        self._main = None
        self._container_image = None
        self._liveness = None
        self._pinned = None
        self._theme = None
        self._extra_head = None
        self._extra_top = None
        self._extra_bottom = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if account is not None:
            self.account = account
        self.creator = creator
        if created is not None:
            self.created = created
        self.name = name
        self.title = title
        self.description = description
        if temporary is not None:
            self.temporary = temporary
        if public is not None:
            self.public = public
        if key is not None:
            self.key = key
        self.main = main
        self.container_image = container_image
        if liveness is not None:
            self.liveness = liveness
        self.pinned = pinned
        if theme is not None:
            self.theme = theme
        self.extra_head = extra_head
        self.extra_top = extra_top
        self.extra_bottom = extra_bottom

    @property
    def id(self):
        """Gets the id of this ProjectUpdate.  # noqa: E501


        :return: The id of this ProjectUpdate.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectUpdate.


        :param id: The id of this ProjectUpdate.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def account(self):
        """Gets the account of this ProjectUpdate.  # noqa: E501

        Account that the project belongs to.  # noqa: E501

        :return: The account of this ProjectUpdate.  # noqa: E501
        :rtype: int
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this ProjectUpdate.

        Account that the project belongs to.  # noqa: E501

        :param account: The account of this ProjectUpdate.  # noqa: E501
        :type account: int
        """

        self._account = account

    @property
    def creator(self):
        """Gets the creator of this ProjectUpdate.  # noqa: E501

        The user who created the project.  # noqa: E501

        :return: The creator of this ProjectUpdate.  # noqa: E501
        :rtype: int
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this ProjectUpdate.

        The user who created the project.  # noqa: E501

        :param creator: The creator of this ProjectUpdate.  # noqa: E501
        :type creator: int
        """

        self._creator = creator

    @property
    def created(self):
        """Gets the created of this ProjectUpdate.  # noqa: E501

        The time the project was created.  # noqa: E501

        :return: The created of this ProjectUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ProjectUpdate.

        The time the project was created.  # noqa: E501

        :param created: The created of this ProjectUpdate.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def name(self):
        """Gets the name of this ProjectUpdate.  # noqa: E501

        Name of the project. Lowercase only and unique for the account. Will be used in URLS e.g. https://hub.stenci.la/awesome-org/great-project.  # noqa: E501

        :return: The name of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectUpdate.

        Name of the project. Lowercase only and unique for the account. Will be used in URLS e.g. https://hub.stenci.la/awesome-org/great-project.  # noqa: E501

        :param name: The name of this ProjectUpdate.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 50):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[-a-zA-Z0-9_]+$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[-a-zA-Z0-9_]+$/`")  # noqa: E501

        self._name = name

    @property
    def title(self):
        """Gets the title of this ProjectUpdate.  # noqa: E501

        Title of the project to display in its profile.  # noqa: E501

        :return: The title of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ProjectUpdate.

        Title of the project to display in its profile.  # noqa: E501

        :param title: The title of this ProjectUpdate.  # noqa: E501
        :type title: str
        """
        if (self.local_vars_configuration.client_side_validation and
                title is not None and len(title) > 256):
            raise ValueError("Invalid value for `title`, length must be less than or equal to `256`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this ProjectUpdate.  # noqa: E501

        Brief description of the project.  # noqa: E501

        :return: The description of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProjectUpdate.

        Brief description of the project.  # noqa: E501

        :param description: The description of this ProjectUpdate.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def temporary(self):
        """Gets the temporary of this ProjectUpdate.  # noqa: E501

        Is the project temporary?  # noqa: E501

        :return: The temporary of this ProjectUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._temporary

    @temporary.setter
    def temporary(self, temporary):
        """Sets the temporary of this ProjectUpdate.

        Is the project temporary?  # noqa: E501

        :param temporary: The temporary of this ProjectUpdate.  # noqa: E501
        :type temporary: bool
        """

        self._temporary = temporary

    @property
    def public(self):
        """Gets the public of this ProjectUpdate.  # noqa: E501

        Is the project publicly visible?  # noqa: E501

        :return: The public of this ProjectUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ProjectUpdate.

        Is the project publicly visible?  # noqa: E501

        :param public: The public of this ProjectUpdate.  # noqa: E501
        :type public: bool
        """

        self._public = public

    @property
    def key(self):
        """Gets the key of this ProjectUpdate.  # noqa: E501

        A unique, and very difficult to guess, key to access this project if it is not public.  # noqa: E501

        :return: The key of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ProjectUpdate.

        A unique, and very difficult to guess, key to access this project if it is not public.  # noqa: E501

        :param key: The key of this ProjectUpdate.  # noqa: E501
        :type key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 64):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def main(self):
        """Gets the main of this ProjectUpdate.  # noqa: E501

        Path of the main file of the project  # noqa: E501

        :return: The main of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._main

    @main.setter
    def main(self, main):
        """Sets the main of this ProjectUpdate.

        Path of the main file of the project  # noqa: E501

        :param main: The main of this ProjectUpdate.  # noqa: E501
        :type main: str
        """

        self._main = main

    @property
    def container_image(self):
        """Gets the container_image of this ProjectUpdate.  # noqa: E501

        The container image to use as the execution environment for this project.  # noqa: E501

        :return: The container_image of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._container_image

    @container_image.setter
    def container_image(self, container_image):
        """Sets the container_image of this ProjectUpdate.

        The container image to use as the execution environment for this project.  # noqa: E501

        :param container_image: The container_image of this ProjectUpdate.  # noqa: E501
        :type container_image: str
        """

        self._container_image = container_image

    @property
    def liveness(self):
        """Gets the liveness of this ProjectUpdate.  # noqa: E501

        Where to serve the content for this project from.  # noqa: E501

        :return: The liveness of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._liveness

    @liveness.setter
    def liveness(self, liveness):
        """Sets the liveness of this ProjectUpdate.

        Where to serve the content for this project from.  # noqa: E501

        :param liveness: The liveness of this ProjectUpdate.  # noqa: E501
        :type liveness: str
        """
        allowed_values = ["live", "latest", "pinned"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and liveness not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `liveness` ({0}), must be one of {1}"  # noqa: E501
                .format(liveness, allowed_values)
            )

        self._liveness = liveness

    @property
    def pinned(self):
        """Gets the pinned of this ProjectUpdate.  # noqa: E501

        If pinned, the snapshot to pin to, when serving content.  # noqa: E501

        :return: The pinned of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._pinned

    @pinned.setter
    def pinned(self, pinned):
        """Sets the pinned of this ProjectUpdate.

        If pinned, the snapshot to pin to, when serving content.  # noqa: E501

        :param pinned: The pinned of this ProjectUpdate.  # noqa: E501
        :type pinned: str
        """

        self._pinned = pinned

    @property
    def theme(self):
        """Gets the theme of this ProjectUpdate.  # noqa: E501

        The name of the theme to use as the default when generating content for this project.  # noqa: E501

        :return: The theme of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._theme

    @theme.setter
    def theme(self, theme):
        """Sets the theme of this ProjectUpdate.

        The name of the theme to use as the default when generating content for this project.  # noqa: E501

        :param theme: The theme of this ProjectUpdate.  # noqa: E501
        :type theme: str
        """
        allowed_values = ["bootstrap", "elife", "f1000", "galleria", "giga", "latex", "nature", "plos", "rpng", "skeleton", "stencila", "tufte", "wilmore"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and theme not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `theme` ({0}), must be one of {1}"  # noqa: E501
                .format(theme, allowed_values)
            )

        self._theme = theme

    @property
    def extra_head(self):
        """Gets the extra_head of this ProjectUpdate.  # noqa: E501

        Content to inject into the <head> element of HTML served for this project.  # noqa: E501

        :return: The extra_head of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_head

    @extra_head.setter
    def extra_head(self, extra_head):
        """Sets the extra_head of this ProjectUpdate.

        Content to inject into the <head> element of HTML served for this project.  # noqa: E501

        :param extra_head: The extra_head of this ProjectUpdate.  # noqa: E501
        :type extra_head: str
        """

        self._extra_head = extra_head

    @property
    def extra_top(self):
        """Gets the extra_top of this ProjectUpdate.  # noqa: E501

        Content to inject at the top of the <body> element of HTML served for this project.  # noqa: E501

        :return: The extra_top of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_top

    @extra_top.setter
    def extra_top(self, extra_top):
        """Sets the extra_top of this ProjectUpdate.

        Content to inject at the top of the <body> element of HTML served for this project.  # noqa: E501

        :param extra_top: The extra_top of this ProjectUpdate.  # noqa: E501
        :type extra_top: str
        """

        self._extra_top = extra_top

    @property
    def extra_bottom(self):
        """Gets the extra_bottom of this ProjectUpdate.  # noqa: E501

        Content to inject at the bottom of the <body> element of HTML served for this project.  # noqa: E501

        :return: The extra_bottom of this ProjectUpdate.  # noqa: E501
        :rtype: str
        """
        return self._extra_bottom

    @extra_bottom.setter
    def extra_bottom(self, extra_bottom):
        """Sets the extra_bottom of this ProjectUpdate.

        Content to inject at the bottom of the <body> element of HTML served for this project.  # noqa: E501

        :param extra_bottom: The extra_bottom of this ProjectUpdate.  # noqa: E501
        :type extra_bottom: str
        """

        self._extra_bottom = extra_bottom

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class ProjectAgentUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'role': 'str',
        'project': 'int',
        'user': 'int',
        'team': 'int'
    }

    attribute_map = {
        'id': 'id',
        'role': 'role',
        'project': 'project',
        'user': 'user',
        'team': 'team'
    }

    def __init__(self, id=None, role=None, project=None, user=None, team=None, local_vars_configuration=None):  # noqa: E501
        """ProjectAgentUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._role = None
        self._project = None
        self._user = None
        self._team = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.role = role
        if project is not None:
            self.project = project
        if user is not None:
            self.user = user
        if team is not None:
            self.team = team

    @property
    def id(self):
        """Gets the id of this ProjectAgentUpdate.  # noqa: E501


        :return: The id of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectAgentUpdate.


        :param id: The id of this ProjectAgentUpdate.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def role(self):
        """Gets the role of this ProjectAgentUpdate.  # noqa: E501

        Role the user or team has within the project.  # noqa: E501

        :return: The role of this ProjectAgentUpdate.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ProjectAgentUpdate.

        Role the user or team has within the project.  # noqa: E501

        :param role: The role of this ProjectAgentUpdate.  # noqa: E501
        :type role: str
        """
        if self.local_vars_configuration.client_side_validation and role is None:  # noqa: E501
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["READER", "REVIEWER", "EDITOR", "AUTHOR", "MANAGER", "OWNER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and role not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def project(self):
        """Gets the project of this ProjectAgentUpdate.  # noqa: E501

        Project to which the user or team is being given access to.  # noqa: E501

        :return: The project of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ProjectAgentUpdate.

        Project to which the user or team is being given access to.  # noqa: E501

        :param project: The project of this ProjectAgentUpdate.  # noqa: E501
        :type project: int
        """

        self._project = project

    @property
    def user(self):
        """Gets the user of this ProjectAgentUpdate.  # noqa: E501

        A user given access to the project.  # noqa: E501

        :return: The user of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ProjectAgentUpdate.

        A user given access to the project.  # noqa: E501

        :param user: The user of this ProjectAgentUpdate.  # noqa: E501
        :type user: int
        """

        self._user = user

    @property
    def team(self):
        """Gets the team of this ProjectAgentUpdate.  # noqa: E501

        A team given access to the project.  # noqa: E501

        :return: The team of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this ProjectAgentUpdate.

        A team given access to the project.  # noqa: E501

        :param team: The team of this ProjectAgentUpdate.  # noqa: E501
        :type team: int
        """

        self._team = team

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectAgentUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectAgentUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class FileList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'is_directory': 'bool',
        'count': 'int',
        'source': 'str',
        'path': 'str',
        'current': 'bool',
        'created': 'datetime',
        'updated': 'datetime',
        'modified': 'datetime',
        'size': 'int',
        'mimetype': 'str',
        'encoding': 'str',
        'fingerprint': 'str',
        'job': 'int',
        'snapshot': 'str',
        'upstreams': 'list[int]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'is_directory': 'isDirectory',
        'count': 'count',
        'source': 'source',
        'path': 'path',
        'current': 'current',
        'created': 'created',
        'updated': 'updated',
        'modified': 'modified',
        'size': 'size',
        'mimetype': 'mimetype',
        'encoding': 'encoding',
        'fingerprint': 'fingerprint',
        'job': 'job',
        'snapshot': 'snapshot',
        'upstreams': 'upstreams'
    }

    def __init__(self, id=None, name=None, is_directory=None, count=None, source=None, path=None, current=None, created=None, updated=None, modified=None, size=None, mimetype=None, encoding=None, fingerprint=None, job=None, snapshot=None, upstreams=None, local_vars_configuration=None):  # noqa: E501
        """FileList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._is_directory = None
        self._count = None
        self._source = None
        self._path = None
        self._current = None
        self._created = None
        self._updated = None
        self._modified = None
        self._size = None
        self._mimetype = None
        self._encoding = None
        self._fingerprint = None
        self._job = None
        self._snapshot = None
        self._upstreams = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if is_directory is not None:
            self.is_directory = is_directory
        if count is not None:
            self.count = count
        if source is not None:
            self.source = source
        self.path = path
        if current is not None:
            self.current = current
        if created is not None:
            self.created = created
        self.updated = updated
        self.modified = modified
        self.size = size
        self.mimetype = mimetype
        self.encoding = encoding
        self.fingerprint = fingerprint
        self.job = job
        self.snapshot = snapshot
        self.upstreams = upstreams

    @property
    def id(self):
        """Gets the id of this FileList.  # noqa: E501


        :return: The id of this FileList.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileList.


        :param id: The id of this FileList.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FileList.  # noqa: E501


        :return: The name of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileList.


        :param name: The name of this FileList.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def is_directory(self):
        """Gets the is_directory of this FileList.  # noqa: E501


        :return: The is_directory of this FileList.  # noqa: E501
        :rtype: bool
        """
        return self._is_directory

    @is_directory.setter
    def is_directory(self, is_directory):
        """Sets the is_directory of this FileList.


        :param is_directory: The is_directory of this FileList.  # noqa: E501
        :type is_directory: bool
        """

        self._is_directory = is_directory

    @property
    def count(self):
        """Gets the count of this FileList.  # noqa: E501


        :return: The count of this FileList.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this FileList.


        :param count: The count of this FileList.  # noqa: E501
        :type count: int
        """

        self._count = count

    @property
    def source(self):
        """Gets the source of this FileList.  # noqa: E501


        :return: The source of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this FileList.


        :param source: The source of this FileList.  # noqa: E501
        :type source: str
        """

        self._source = source

    @property
    def path(self):
        """Gets the path of this FileList.  # noqa: E501

        The path of the file within the project.  # noqa: E501

        :return: The path of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FileList.

        The path of the file within the project.  # noqa: E501

        :param path: The path of this FileList.  # noqa: E501
        :type path: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                path is not None and len(path) < 1):
            raise ValueError("Invalid value for `path`, length must be greater than or equal to `1`")  # noqa: E501

        self._path = path

    @property
    def current(self):
        """Gets the current of this FileList.  # noqa: E501

        Is the file currently in the project? Used to retain a history for file paths within a project.  # noqa: E501

        :return: The current of this FileList.  # noqa: E501
        :rtype: bool
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this FileList.

        Is the file currently in the project? Used to retain a history for file paths within a project.  # noqa: E501

        :param current: The current of this FileList.  # noqa: E501
        :type current: bool
        """

        self._current = current

    @property
    def created(self):
        """Gets the created of this FileList.  # noqa: E501

        The time the file info was created.  # noqa: E501

        :return: The created of this FileList.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FileList.

        The time the file info was created.  # noqa: E501

        :param created: The created of this FileList.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this FileList.  # noqa: E501

        The time the file info was updated. This field will have the last time this row was altered (i.e. changed from current, to not).  # noqa: E501

        :return: The updated of this FileList.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this FileList.

        The time the file info was updated. This field will have the last time this row was altered (i.e. changed from current, to not).  # noqa: E501

        :param updated: The updated of this FileList.  # noqa: E501
        :type updated: datetime
        """

        self._updated = updated

    @property
    def modified(self):
        """Gets the modified of this FileList.  # noqa: E501

        The file modification time.  # noqa: E501

        :return: The modified of this FileList.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this FileList.

        The file modification time.  # noqa: E501

        :param modified: The modified of this FileList.  # noqa: E501
        :type modified: datetime
        """

        self._modified = modified

    @property
    def size(self):
        """Gets the size of this FileList.  # noqa: E501

        The size of the file in bytes  # noqa: E501

        :return: The size of this FileList.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FileList.

        The size of the file in bytes  # noqa: E501

        :param size: The size of this FileList.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def mimetype(self):
        """Gets the mimetype of this FileList.  # noqa: E501

        The mimetype of the file.  # noqa: E501

        :return: The mimetype of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._mimetype

    @mimetype.setter
    def mimetype(self, mimetype):
        """Sets the mimetype of this FileList.

        The mimetype of the file.  # noqa: E501

        :param mimetype: The mimetype of this FileList.  # noqa: E501
        :type mimetype: str
        """
        if (self.local_vars_configuration.client_side_validation and
                mimetype is not None and len(mimetype) > 512):
            raise ValueError("Invalid value for `mimetype`, length must be less than or equal to `512`")  # noqa: E501

        self._mimetype = mimetype

    @property
    def encoding(self):
        """Gets the encoding of this FileList.  # noqa: E501

        The encoding of the file e.g. gzip  # noqa: E501

        :return: The encoding of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this FileList.

        The encoding of the file e.g. gzip  # noqa: E501

        :param encoding: The encoding of this FileList.  # noqa: E501
        :type encoding: str
        """
        if (self.local_vars_configuration.client_side_validation and
                encoding is not None and len(encoding) > 512):
            raise ValueError("Invalid value for `encoding`, length must be less than or equal to `512`")  # noqa: E501

        self._encoding = encoding

    @property
    def fingerprint(self):
        """Gets the fingerprint of this FileList.  # noqa: E501

        The fingerprint of the file  # noqa: E501

        :return: The fingerprint of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this FileList.

        The fingerprint of the file  # noqa: E501

        :param fingerprint: The fingerprint of this FileList.  # noqa: E501
        :type fingerprint: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fingerprint is not None and len(fingerprint) > 128):
            raise ValueError("Invalid value for `fingerprint`, length must be less than or equal to `128`")  # noqa: E501

        self._fingerprint = fingerprint

    @property
    def job(self):
        """Gets the job of this FileList.  # noqa: E501

        The job that created the file e.g. a source pull or file conversion.  # noqa: E501

        :return: The job of this FileList.  # noqa: E501
        :rtype: int
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this FileList.

        The job that created the file e.g. a source pull or file conversion.  # noqa: E501

        :param job: The job of this FileList.  # noqa: E501
        :type job: int
        """

        self._job = job

    @property
    def snapshot(self):
        """Gets the snapshot of this FileList.  # noqa: E501

        The snapshot that the file belongs. If the snapshot is deleted so will the files.  # noqa: E501

        :return: The snapshot of this FileList.  # noqa: E501
        :rtype: str
        """
        return self._snapshot

    @snapshot.setter
    def snapshot(self, snapshot):
        """Sets the snapshot of this FileList.

        The snapshot that the file belongs. If the snapshot is deleted so will the files.  # noqa: E501

        :param snapshot: The snapshot of this FileList.  # noqa: E501
        :type snapshot: str
        """

        self._snapshot = snapshot

    @property
    def upstreams(self):
        """Gets the upstreams of this FileList.  # noqa: E501

        The files that this file was derived from (if any).  # noqa: E501

        :return: The upstreams of this FileList.  # noqa: E501
        :rtype: list[int]
        """
        return self._upstreams

    @upstreams.setter
    def upstreams(self, upstreams):
        """Sets the upstreams of this FileList.

        The files that this file was derived from (if any).  # noqa: E501

        :param upstreams: The upstreams of this FileList.  # noqa: E501
        :type upstreams: list[int]
        """
        if self.local_vars_configuration.client_side_validation and upstreams is None:  # noqa: E501
            raise ValueError("Invalid value for `upstreams`, must not be `None`")  # noqa: E501

        self._upstreams = upstreams

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileList):
            return True

        return self.to_dict() != other.to_dict()
